<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/filmset/page',
        dialogNeedRequest: true,
        persistSelection: true,
        columns: [
          { type: 'selection' },
          { label: '标题', prop: 'title' },
          { label: '发布日期', prop: 'publishDate' },
          { label: '编辑日期', prop: 'updateTime' },
          { label: '状态', prop: 'statusStr' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              { label: '标题', id: 'title', type: 'input' },
              {
                label: '创建日期',
                id: 'createDateBeginStr',
                component: 'el-bus-date-range',
                commonFormat: true,
                commonFormatProps: ['createDateBeginStr', 'createDateEndStr'],
                customClass: 'in-bus-form',
              },
            ],
          },
        ],
        form: [
          {
            label: '标题：',
            id: 'title',
            type: 'input',
            rules: {
              required: true,
              message: '请输入标题',
              trigger: 'blur',
            },
          },
          {
            label: '片场内容类型：',
            id: 'type',
            type: 'bus-select-dict',
            el: {
              code: 'FILMSET_TYPE',
              style: 'width:100%',
              clearable: true,
            },
            rules: {
              required: true,
              message: '请选择片场内容类型',
            },
          },
          {
            label: '内容：',
            id: 'content',
            component: 'base-editor',
            richText: true,
            rules: { required: true, message: '请输入内容', trigger: 'blur' },
          },
          // {
          //   label: '封面：',
          //   id: 'cover',
          //   type: 'bus-upload',
          //   el: {
          //     listType: 'picture-card',
          //     limitSize: 2,
          //     limit: 1,
          //     tipText: '大小不超过2M',
          //     valueType: 'string',
          //   },
          //   forceDisabled: true,
          // },
        ],
        extraButtons: [
          {
            text: (row) => (row.status === 'unpublished' ? '发布' : '下架'),
            atClick: async (row) => {
              const action = row.status === 'unpublished' ? '发布' : '下架'
              try {
                await this.$elBusUtil.confirm(`确定要${action}吗？`)
                const { code } = await this.$elBusHttp.request(
                  'flower/api/filmset/page/changeStatus',
                  { params: { id: row.id } }
                )
                if (code === 0) {
                  this.$message.success(`${action}成功`)
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
        headerButtons: [
          {
            text: '批量发布',
            type: 'primary',
            disabled: (selected) =>
              selected.filter((item) => item.status === 'unpublished')
                .length === 0,
            atClick: async (selected) => {
              const selectedNotice = selected.filter(
                (item) => item.status === 'unpublished'
              )
              try {
                await this.$elBusUtil.confirm(
                  `确定要批量发布这${selectedNotice.length}个片场内容吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/filmset/page/publish/batch',
                  {
                    method: 'post',
                    data: {
                      ids: selected.map((item) => item.id),
                    },
                  }
                )
                if (code === 0) {
                  this.$message.success('操作成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '批量删除',
            type: 'danger',
            disabled: (selected) => selected.length === 0,
            atClick: async (selected) => {
              try {
                await this.$elBusUtil.confirm(
                  `确定要批量删除这${selected.length}个片场内容吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/filmset/page/delete/batch',
                  {
                    method: 'post',
                    data: {
                      ids: selected.map((item) => item.id),
                    },
                  }
                )
                if (code === 0) {
                  this.$message.success('操作成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '片场内容管理',
    }
  },
}
</script>

<style lang="scss" scoped>
::v-deep {
  .el-upload {
    &-list__item {
      width: 345px;
      height: 128px;
    }
    &.el-upload--picture-card {
      width: 345px;
      height: 128px;
    }
  }
}
</style>
